@@ -32,19 +32,16 @@ class EncryptedCharField(mixins.EncryptedMixin, models.CharField):
     pass
 
 
-class EncryptedDateField(mixins.DateMixin, mixins.EncryptedMixin, models.DateField):
+class EncryptedDateField(mixins.EncryptedMixin, models.DateField):
     pass
 
 
-class EncryptedDateTimeField(mixins.DateMixin, mixins.EncryptedMixin, models.DateTimeField):
+class EncryptedDateTimeField(mixins.EncryptedMixin, models.DateTimeField):
     pass
 
 
 class EncryptedDecimalField(mixins.EncryptedMixin, models.DecimalField):
-
-    def get_db_prep_save(self, value, connection):
-        value = super().get_db_prep_save(value, connection)
-        return self.get_db_prep_value(value, connection, prepared=False)
+    pass
 
 
 class EncryptedIntegerField(mixins.EncryptedMixin, models.IntegerField):
